package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Feb 2, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Dir returns the configuration directory path, respecting XDG_CONFIG_HOME.
Save writes configuration to disk with secure file permissions.
type Config struct {
AppID int64 `yaml:"app_id"`
InstallationID int64 `yaml:"installation_id"`
PrivateKeyPath string `yaml:"private_key_path"`
}
Config holds GitHub App credentials.
Load reads configuration from disk.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.